cheesecake.subprocess.ProcessError

Package cheesecake :: Module subprocess :: Class ProcessError |
[show private | hide private]
[frames | no frames]

## Class ProcessError

    Exception --+
                |
               ProcessError

This exception is raised when there is an error calling a subprocess.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net